==> openshift-model-operator-6.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ExportNetworkFlowsFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExportNetworkFlowsFluentImpl<A extends ExportNetworkFlowsFluent<A>> extends BaseFluent<A> implements ExportNetworkFlowsFluent<A>{
  public ExportNetworkFlowsFluentImpl() {
  }
  public ExportNetworkFlowsFluentImpl(ExportNetworkFlows instance) {
    this.withIpfix(instance.getIpfix()); 
    this.withNetFlow(instance.getNetFlow()); 
    this.withSFlow(instance.getSFlow()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private IPFIXConfigBuilder ipfix;
  private NetFlowConfigBuilder netFlow;
  private SFlowConfigBuilder sFlow;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIpfix instead.
   * @return The buildable object.
   */
  @Deprecated
  public IPFIXConfig getIpfix() {
    return this.ipfix!=null ?this.ipfix.build():null;
  }
  public IPFIXConfig buildIpfix() {
    return this.ipfix!=null ?this.ipfix.build():null;
  }
  public A withIpfix(IPFIXConfig ipfix) {
    _visitables.get("ipfix").remove(this.ipfix);
    if (ipfix!=null){ this.ipfix= new IPFIXConfigBuilder(ipfix); _visitables.get("ipfix").add(this.ipfix);} else { this.ipfix = null; _visitables.get("ipfix").remove(this.ipfix); } return (A) this;
  }
  public Boolean hasIpfix() {
    return this.ipfix != null;
  }
  public ExportNetworkFlowsFluent.IpfixNested<A> withNewIpfix() {
    return new ExportNetworkFlowsFluentImpl.IpfixNestedImpl();
  }
  public ExportNetworkFlowsFluent.IpfixNested<A> withNewIpfixLike(IPFIXConfig item) {
    return new ExportNetworkFlowsFluentImpl.IpfixNestedImpl(item);
  }
  public ExportNetworkFlowsFluent.IpfixNested<A> editIpfix() {
    return withNewIpfixLike(getIpfix());
  }
  public ExportNetworkFlowsFluent.IpfixNested<A> editOrNewIpfix() {
    return withNewIpfixLike(getIpfix() != null ? getIpfix(): new IPFIXConfigBuilder().build());
  }
  public ExportNetworkFlowsFluent.IpfixNested<A> editOrNewIpfixLike(IPFIXConfig item) {
    return withNewIpfixLike(getIpfix() != null ? getIpfix(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNetFlow instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetFlowConfig getNetFlow() {
    return this.netFlow!=null ?this.netFlow.build():null;
  }
  public NetFlowConfig buildNetFlow() {
    return this.netFlow!=null ?this.netFlow.build():null;
  }
  public A withNetFlow(NetFlowConfig netFlow) {
    _visitables.get("netFlow").remove(this.netFlow);
    if (netFlow!=null){ this.netFlow= new NetFlowConfigBuilder(netFlow); _visitables.get("netFlow").add(this.netFlow);} else { this.netFlow = null; _visitables.get("netFlow").remove(this.netFlow); } return (A) this;
  }
  public Boolean hasNetFlow() {
    return this.netFlow != null;
  }
  public ExportNetworkFlowsFluent.NetFlowNested<A> withNewNetFlow() {
    return new ExportNetworkFlowsFluentImpl.NetFlowNestedImpl();
  }
  public ExportNetworkFlowsFluent.NetFlowNested<A> withNewNetFlowLike(NetFlowConfig item) {
    return new ExportNetworkFlowsFluentImpl.NetFlowNestedImpl(item);
  }
  public ExportNetworkFlowsFluent.NetFlowNested<A> editNetFlow() {
    return withNewNetFlowLike(getNetFlow());
  }
  public ExportNetworkFlowsFluent.NetFlowNested<A> editOrNewNetFlow() {
    return withNewNetFlowLike(getNetFlow() != null ? getNetFlow(): new NetFlowConfigBuilder().build());
  }
  public ExportNetworkFlowsFluent.NetFlowNested<A> editOrNewNetFlowLike(NetFlowConfig item) {
    return withNewNetFlowLike(getNetFlow() != null ? getNetFlow(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSFlow instead.
   * @return The buildable object.
   */
  @Deprecated
  public SFlowConfig getSFlow() {
    return this.sFlow!=null ?this.sFlow.build():null;
  }
  public SFlowConfig buildSFlow() {
    return this.sFlow!=null ?this.sFlow.build():null;
  }
  public A withSFlow(SFlowConfig sFlow) {
    _visitables.get("sFlow").remove(this.sFlow);
    if (sFlow!=null){ this.sFlow= new SFlowConfigBuilder(sFlow); _visitables.get("sFlow").add(this.sFlow);} else { this.sFlow = null; _visitables.get("sFlow").remove(this.sFlow); } return (A) this;
  }
  public Boolean hasSFlow() {
    return this.sFlow != null;
  }
  public ExportNetworkFlowsFluent.SFlowNested<A> withNewSFlow() {
    return new ExportNetworkFlowsFluentImpl.SFlowNestedImpl();
  }
  public ExportNetworkFlowsFluent.SFlowNested<A> withNewSFlowLike(SFlowConfig item) {
    return new ExportNetworkFlowsFluentImpl.SFlowNestedImpl(item);
  }
  public ExportNetworkFlowsFluent.SFlowNested<A> editSFlow() {
    return withNewSFlowLike(getSFlow());
  }
  public ExportNetworkFlowsFluent.SFlowNested<A> editOrNewSFlow() {
    return withNewSFlowLike(getSFlow() != null ? getSFlow(): new SFlowConfigBuilder().build());
  }
  public ExportNetworkFlowsFluent.SFlowNested<A> editOrNewSFlowLike(SFlowConfig item) {
    return withNewSFlowLike(getSFlow() != null ? getSFlow(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExportNetworkFlowsFluentImpl that = (ExportNetworkFlowsFluentImpl) o;
    if (ipfix != null ? !ipfix.equals(that.ipfix) :that.ipfix != null) return false;
    if (netFlow != null ? !netFlow.equals(that.netFlow) :that.netFlow != null) return false;
    if (sFlow != null ? !sFlow.equals(that.sFlow) :that.sFlow != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ipfix,  netFlow,  sFlow,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ipfix != null) { sb.append("ipfix:"); sb.append(ipfix + ","); }
    if (netFlow != null) { sb.append("netFlow:"); sb.append(netFlow + ","); }
    if (sFlow != null) { sb.append("sFlow:"); sb.append(sFlow + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IpfixNestedImpl<N> extends IPFIXConfigFluentImpl<ExportNetworkFlowsFluent.IpfixNested<N>> implements ExportNetworkFlowsFluent.IpfixNested<N>,Nested<N>{
    IpfixNestedImpl(IPFIXConfig item) {
      this.builder = new IPFIXConfigBuilder(this, item);
    }
    IpfixNestedImpl() {
      this.builder = new IPFIXConfigBuilder(this);
    }
    IPFIXConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withIpfix(builder.build());
    }
    public N endIpfix() {
      return and();
    }
    
  }
  class NetFlowNestedImpl<N> extends NetFlowConfigFluentImpl<ExportNetworkFlowsFluent.NetFlowNested<N>> implements ExportNetworkFlowsFluent.NetFlowNested<N>,Nested<N>{
    NetFlowNestedImpl(NetFlowConfig item) {
      this.builder = new NetFlowConfigBuilder(this, item);
    }
    NetFlowNestedImpl() {
      this.builder = new NetFlowConfigBuilder(this);
    }
    NetFlowConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withNetFlow(builder.build());
    }
    public N endNetFlow() {
      return and();
    }
    
  }
  class SFlowNestedImpl<N> extends SFlowConfigFluentImpl<ExportNetworkFlowsFluent.SFlowNested<N>> implements ExportNetworkFlowsFluent.SFlowNested<N>,Nested<N>{
    SFlowNestedImpl(SFlowConfig item) {
      this.builder = new SFlowConfigBuilder(this, item);
    }
    SFlowNestedImpl() {
      this.builder = new SFlowConfigBuilder(this);
    }
    SFlowConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withSFlow(builder.build());
    }
    public N endSFlow() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ExportNetworkFlowsFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExportNetworkFlowsFluentImpl<A extends ExportNetworkFlowsFluent<A>> extends BaseFluent<A> implements ExportNetworkFlowsFluent<A>{
  public ExportNetworkFlowsFluentImpl() {
  }
  public ExportNetworkFlowsFluentImpl(ExportNetworkFlows instance) {
    if (instance != null) {
      this.withIpfix(instance.getIpfix());
      this.withNetFlow(instance.getNetFlow());
      this.withSFlow(instance.getSFlow());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private IPFIXConfigBuilder ipfix;
  private NetFlowConfigBuilder netFlow;
  private SFlowConfigBuilder sFlow;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIpfix instead.
   * @return The buildable object.
   */
  @Deprecated
  public IPFIXConfig getIpfix() {
    return this.ipfix!=null ?this.ipfix.build():null;
  }
  public IPFIXConfig buildIpfix() {
    return this.ipfix!=null ?this.ipfix.build():null;
  }
  public A withIpfix(IPFIXConfig ipfix) {
    _visitables.get("ipfix").remove(this.ipfix);
    if (ipfix!=null){ this.ipfix= new IPFIXConfigBuilder(ipfix); _visitables.get("ipfix").add(this.ipfix);} else { this.ipfix = null; _visitables.get("ipfix").remove(this.ipfix); } return (A) this;
  }
  public Boolean hasIpfix() {
    return this.ipfix != null;
  }
  public ExportNetworkFlowsFluentImpl.IpfixNested<A> withNewIpfix() {
    return new ExportNetworkFlowsFluentImpl.IpfixNestedImpl();
  }
  public ExportNetworkFlowsFluentImpl.IpfixNested<A> withNewIpfixLike(IPFIXConfig item) {
    return new ExportNetworkFlowsFluentImpl.IpfixNestedImpl(item);
  }
  public ExportNetworkFlowsFluentImpl.IpfixNested<A> editIpfix() {
    return withNewIpfixLike(getIpfix());
  }
  public ExportNetworkFlowsFluentImpl.IpfixNested<A> editOrNewIpfix() {
    return withNewIpfixLike(getIpfix() != null ? getIpfix(): new IPFIXConfigBuilder().build());
  }
  public ExportNetworkFlowsFluentImpl.IpfixNested<A> editOrNewIpfixLike(IPFIXConfig item) {
    return withNewIpfixLike(getIpfix() != null ? getIpfix(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNetFlow instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetFlowConfig getNetFlow() {
    return this.netFlow!=null ?this.netFlow.build():null;
  }
  public NetFlowConfig buildNetFlow() {
    return this.netFlow!=null ?this.netFlow.build():null;
  }
  public A withNetFlow(NetFlowConfig netFlow) {
    _visitables.get("netFlow").remove(this.netFlow);
    if (netFlow!=null){ this.netFlow= new NetFlowConfigBuilder(netFlow); _visitables.get("netFlow").add(this.netFlow);} else { this.netFlow = null; _visitables.get("netFlow").remove(this.netFlow); } return (A) this;
  }
  public Boolean hasNetFlow() {
    return this.netFlow != null;
  }
  public ExportNetworkFlowsFluentImpl.NetFlowNested<A> withNewNetFlow() {
    return new ExportNetworkFlowsFluentImpl.NetFlowNestedImpl();
  }
  public ExportNetworkFlowsFluentImpl.NetFlowNested<A> withNewNetFlowLike(NetFlowConfig item) {
    return new ExportNetworkFlowsFluentImpl.NetFlowNestedImpl(item);
  }
  public ExportNetworkFlowsFluentImpl.NetFlowNested<A> editNetFlow() {
    return withNewNetFlowLike(getNetFlow());
  }
  public ExportNetworkFlowsFluentImpl.NetFlowNested<A> editOrNewNetFlow() {
    return withNewNetFlowLike(getNetFlow() != null ? getNetFlow(): new NetFlowConfigBuilder().build());
  }
  public ExportNetworkFlowsFluentImpl.NetFlowNested<A> editOrNewNetFlowLike(NetFlowConfig item) {
    return withNewNetFlowLike(getNetFlow() != null ? getNetFlow(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSFlow instead.
   * @return The buildable object.
   */
  @Deprecated
  public SFlowConfig getSFlow() {
    return this.sFlow!=null ?this.sFlow.build():null;
  }
  public SFlowConfig buildSFlow() {
    return this.sFlow!=null ?this.sFlow.build():null;
  }
  public A withSFlow(SFlowConfig sFlow) {
    _visitables.get("sFlow").remove(this.sFlow);
    if (sFlow!=null){ this.sFlow= new SFlowConfigBuilder(sFlow); _visitables.get("sFlow").add(this.sFlow);} else { this.sFlow = null; _visitables.get("sFlow").remove(this.sFlow); } return (A) this;
  }
  public Boolean hasSFlow() {
    return this.sFlow != null;
  }
  public ExportNetworkFlowsFluentImpl.SFlowNested<A> withNewSFlow() {
    return new ExportNetworkFlowsFluentImpl.SFlowNestedImpl();
  }
  public ExportNetworkFlowsFluentImpl.SFlowNested<A> withNewSFlowLike(SFlowConfig item) {
    return new ExportNetworkFlowsFluentImpl.SFlowNestedImpl(item);
  }
  public ExportNetworkFlowsFluentImpl.SFlowNested<A> editSFlow() {
    return withNewSFlowLike(getSFlow());
  }
  public ExportNetworkFlowsFluentImpl.SFlowNested<A> editOrNewSFlow() {
    return withNewSFlowLike(getSFlow() != null ? getSFlow(): new SFlowConfigBuilder().build());
  }
  public ExportNetworkFlowsFluentImpl.SFlowNested<A> editOrNewSFlowLike(SFlowConfig item) {
    return withNewSFlowLike(getSFlow() != null ? getSFlow(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExportNetworkFlowsFluentImpl that = (ExportNetworkFlowsFluentImpl) o;
    if (!java.util.Objects.equals(ipfix, that.ipfix)) return false;

    if (!java.util.Objects.equals(netFlow, that.netFlow)) return false;

    if (!java.util.Objects.equals(sFlow, that.sFlow)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ipfix,  netFlow,  sFlow,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ipfix != null) { sb.append("ipfix:"); sb.append(ipfix + ","); }
    if (netFlow != null) { sb.append("netFlow:"); sb.append(netFlow + ","); }
    if (sFlow != null) { sb.append("sFlow:"); sb.append(sFlow + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IpfixNestedImpl<N> extends IPFIXConfigFluentImpl<ExportNetworkFlowsFluentImpl.IpfixNested<N>> implements ExportNetworkFlowsFluentImpl.IpfixNested<N>,Nested<N>{
    IpfixNestedImpl(IPFIXConfig item) {
      this.builder = new IPFIXConfigBuilder(this, item);
    }
    IpfixNestedImpl() {
      this.builder = new IPFIXConfigBuilder(this);
    }
    IPFIXConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withIpfix(builder.build());
    }
    public N endIpfix() {
      return and();
    }
    
  }
  class NetFlowNestedImpl<N> extends NetFlowConfigFluentImpl<ExportNetworkFlowsFluentImpl.NetFlowNested<N>> implements ExportNetworkFlowsFluentImpl.NetFlowNested<N>,Nested<N>{
    NetFlowNestedImpl(NetFlowConfig item) {
      this.builder = new NetFlowConfigBuilder(this, item);
    }
    NetFlowNestedImpl() {
      this.builder = new NetFlowConfigBuilder(this);
    }
    NetFlowConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withNetFlow(builder.build());
    }
    public N endNetFlow() {
      return and();
    }
    
  }
  class SFlowNestedImpl<N> extends SFlowConfigFluentImpl<ExportNetworkFlowsFluentImpl.SFlowNested<N>> implements ExportNetworkFlowsFluentImpl.SFlowNested<N>,Nested<N>{
    SFlowNestedImpl(SFlowConfig item) {
      this.builder = new SFlowConfigBuilder(this, item);
    }
    SFlowNestedImpl() {
      this.builder = new SFlowConfigBuilder(this);
    }
    SFlowConfigBuilder builder;
    public N and() {
      return (N) ExportNetworkFlowsFluentImpl.this.withSFlow(builder.build());
    }
    public N endSFlow() {
      return and();
    }
    
  }
  
}
